==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/dao/DsConstants.java <==
package cn.com.duiba.activity.center.biz.dao;

import java.util.Arrays;
import java.util.List;

/**
 * Created by wenqi.huang on 16/4/14.
 */
public class DsConstants {

    /**
     * credits数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS)
     */
    public static final String     DATABASE_CREDITS          = "credits";

    /**
     * credits_game数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_GAME)
     */
    public static final String     DATABASE_CREDITS_GAME     = "creditsGame";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_QUIZZ)
     */
    public static final String     DATABASE_QUIZZ            = "quizz";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CONSUMER_QUIZZ)
     */
    public static final String     DATABASE_QUIZZ_CONSUMER   = "quizzConsumer";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_QUIZZ_APP)
     */
    public static final String     DATABASE_QUIZZ_APP        = "quizzApp";
    /**
     * seckill数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_SECKILL)
     */
    public static final String     DATABASE_SECKILL          = "seckill";
    /**
     * creditsActivity数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_ACTIVITY)
     */
    public static final String     DATABASE_CREDITS_ACTIVITY = "creditsActivity";
    /**
     * manager 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_MANAGER)
     */
    public static final String     DATABASE_MANAGER          = "manager";
    /**
     * ngame 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME)
     */
    public static final String     DATABASE_NGAME          = "ngame";
    /**
     * ngame_app 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME_APP)
     */
    public static final String     DATABASE_NGAME_APP          = "ngameApp";
    /**
     * ngame_con 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME_CON)
     */
    public static final String     DATABASE_NGAME_CON          = "ngameCon";
    /**
     * consumer数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CONSUMER)
     */
    public static final String     DATABASE_CONSUMER         = "consumer";

    /**
     * 线上测试专用优惠券ItemId
     */
    public static final List<Long> TEST_COUPON               = Arrays.asList(191L);

    public static int              ITEM_TOP_START            = 1000000;            // 置顶项的起始权重,来自DevCustomManagerImpl
    public static int              ITEM_TOP_NUM              = 3;                  // 每个APP可以置顶数目,来自DevCustomManagerImpl
}

==> activity-center-biz-1.2.3.2-20160831.081205-1-sources.jar: cn/com/duiba/activity/center/biz/dao/DsConstants.java <==
package cn.com.duiba.activity.center.biz.dao;

import java.util.Arrays;
import java.util.List;

/**
 * Created by wenqi.huang on 16/4/14.
 */
public class DsConstants {

    /**
     * credits数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS)
     */
    public static final String     DATABASE_CREDITS          = "credits";

    /**
     * credits_game数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_GAME)
     */
    public static final String     DATABASE_CREDITS_GAME     = "creditsGame";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_QUIZZ)
     */
    public static final String     DATABASE_QUIZZ            = "quizz";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CONSUMER_QUIZZ)
     */
    public static final String     DATABASE_QUIZZ_CONSUMER   = "quizzConsumer";

    /**
     * quizz数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_QUIZZ_APP)
     */
    public static final String     DATABASE_QUIZZ_APP        = "quizzApp";
    /**
     * seckill数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_SECKILL)
     */
    public static final String     DATABASE_SECKILL          = "seckill";
    /**
     * seckill数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_SECKILL_APP)
     */
    public static final String     DATABASE_SECKILL_APP        = "seckillApp";
    /**
     * creditsActivity数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_ACTIVITY)
     */
    public static final String     DATABASE_CREDITS_ACTIVITY = "creditsActivity";
    /**
     * manager 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_MANAGER)
     */
    public static final String     DATABASE_MANAGER          = "manager";
    /**
     * ngame 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME)
     */
    public static final String     DATABASE_NGAME          = "ngame";
    /**
     * ngame_app 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME_APP)
     */
    public static final String     DATABASE_NGAME_APP          = "ngameApp";
    /**
     * ngame_con 数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_NGAME_CON)
     */
    public static final String     DATABASE_NGAME_CON          = "ngameCon";
    /**
     * consumer数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CONSUMER)
     */
    public static final String     DATABASE_CONSUMER         = "consumer";

    /**
     * mng_hdtool数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_MNG_HDTOOL)
     */
    public static final String     DATABASE_MNG_HDTOOL          = "mngHdtool";

    /**
     * app_hdtool数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_APP_HDTOOL)
     */
    public static final String     DATABASE_APP_HDTOOL          = "appHdtool";

    /**
     * credits_hdtool数据库,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_HDTOOL)
     */
    public static final String     DATABASE_CREDITS_HDTOOL          = "creditsHdtool";

    /**
     * guess,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_GUESS)
     */
    public static final String     DATABASE_GUESS          = "guess";


    /**
     * guessApp,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_GUESS_APP)
     */
    public static final String     DATABASE_GUESS_APP          = "guessApp";


    /**
     * guessCon,用于在事务注解中声明事务发生在哪个数据库上,比如@Transactional(DsConstants.DATABASE_CREDITS_GUESS)
     */
    public static final String     DATABASE_GUESS_CON          = "guessCon";


    /**
     * 线上测试专用优惠券ItemId
     */
    public static List<Long> TEST_COUPON               = Arrays.asList(191L);

    public static int              ITEM_TOP_START            = 1000000;            // 置顶项的起始权重,来自DevCustomManagerImpl
    public static int              ITEM_TOP_NUM              = 3;                  // 每个APP可以置顶数目,来自DevCustomManagerImpl
}
